package com.yunfeiyun.agmp.fms.service.impl;

import java.util.List;

import com.yunfeiyun.agmp.fms.domain.WmsChange;
import com.yunfeiyun.agmp.fms.mapper.WmsChangeMapper;
import com.yunfeiyun.agmp.fms.domain.reqvo.WmsChangeReqVo;
import com.yunfeiyun.agmp.fms.domain.resvo.WmsChangeResVo;
import com.yunfeiyun.agmp.fms.service.IWmsChangeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 变动Service业务层处理
 * 
 * @author 杨晓辉
 * @date 2023-05-25
 */
@Service
public class WmsChangeServiceImpl implements IWmsChangeService
{
    @Autowired
    private WmsChangeMapper wmsChangeMapper;

    /**
     * 查询变动
     * 
     * @param changeId 变动主键
     * @return 变动
     */
    @Override
    public WmsChange selectWmsChangeByChangeId(String changeId)
    {
        return wmsChangeMapper.selectWmsChangeByChangeId(changeId);
    }

    /**
     * 查询变动列表
     * 
     * @param wmsChange 变动
     * @return 变动
     */
    @Override
    public List<WmsChange> selectWmsChangeList(WmsChange wmsChange)
    {
        return wmsChangeMapper.selectWmsChangeList(wmsChange);
    }

    @Override
    public List<WmsChangeResVo> selectWmsChangeListOfFinishGoods(WmsChangeReqVo reqVo) {
        return wmsChangeMapper.selectWmsChangeListOfFinishGoods(reqVo);
    }

    /**
     * 新增变动
     * 
     * @param wmsChange 变动
     * @return 结果
     */
    @Override
    public int insertWmsChange(WmsChange wmsChange)
    {
        return wmsChangeMapper.insertWmsChange(wmsChange);
    }

    /**
     * 修改变动
     * 
     * @param wmsChange 变动
     * @return 结果
     */
    @Override
    public int updateWmsChange(WmsChange wmsChange)
    {
        return wmsChangeMapper.updateWmsChange(wmsChange);
    }

    /**
     * 批量删除变动
     * 
     * @param changeIds 需要删除的变动主键
     * @return 结果
     */
    @Override
    public int deleteWmsChangeByChangeIds(String[] changeIds)
    {
        return wmsChangeMapper.deleteWmsChangeByChangeIds(changeIds);
    }

    /**
     * 删除变动信息
     * 
     * @param changeId 变动主键
     * @return 结果
     */
    @Override
    public int deleteWmsChangeByChangeId(String changeId)
    {
        return wmsChangeMapper.deleteWmsChangeByChangeId(changeId);
    }
}
